{% extends 'layout.html' %}
{% block title %}404 Not Found{% endblock %}
{% block content %}

<h1>404 Not Found</h1>
<p>This is not the page you're looking for. You might have better luck with <a href="{{conf.web_prefix}}/{{conf.search_tpl}}">search</a>.</p>

{% endblock %}
