{% extends 'layout.html' %}
{% block title %}Recent{% endblock %}
{% block content %}
<script>
$(document).ready(function() { 
    window.location = '{{conf.web_prefix}}/postlist-1.html';
});
</script>
{% endblock %}
